summaryrefslogtreecommitdiff
path: root/src/expr/node_manager.cpp
diff options
context:
space:
mode:
authorAina Niemetz <aina.niemetz@gmail.com>2021-03-31 15:23:17 -0700
committerGitHub <noreply@github.com>2021-03-31 22:23:17 +0000
commita1466978fbc328507406d4a121dab4d1a1047e1d (patch)
tree12b40f161bb4d7a6ee40c20c78a15d6cda3c1995 /src/expr/node_manager.cpp
parentf9a9af855fb65804ff0b36e764ccd9d0fa9f87f8 (diff)
Rename namespace CVC4 to CVC5. (#6249)
Diffstat (limited to 'src/expr/node_manager.cpp')
-rw-r--r--src/expr/node_manager.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/expr/node_manager.cpp b/src/expr/node_manager.cpp
index a5329147b..370f0fb4c 100644
--- a/src/expr/node_manager.cpp
+++ b/src/expr/node_manager.cpp
@@ -35,9 +35,9 @@
#include "util/resource_manager.h"
using namespace std;
-using namespace CVC4::expr;
+using namespace CVC5::expr;
-namespace CVC4 {
+namespace CVC5 {
thread_local NodeManager* NodeManager::s_current = NULL;
@@ -87,7 +87,7 @@ struct NVReclaim {
namespace attr {
struct LambdaBoundVarListTag { };
-}/* CVC4::attr namespace */
+ } // namespace attr
// attribute that stores the canonical bound variable list for function types
typedef expr::Attribute<attr::LambdaBoundVarListTag, Node> LambdaBoundVarListAttr;
@@ -373,7 +373,7 @@ void NodeManager::reclaimZombies() {
if(mk == kind::metakind::CONSTANT) {
// Destroy (call the destructor for) the C++ type representing
// the constant in this NodeValue. This is needed for
// e.g. CVC4::Rational, since it has a gmp internal
// representation that mallocs memory and should be cleaned
// up. (This won't delete a pointer value if used as a
// constant, but then, you should probably use a smart-pointer
@@ -678,7 +678,7 @@ std::vector<TypeNode> NodeManager::mkMutualDatatypeTypes(
<< "malformed selector in datatype post-resolution";
// This next one's a "hard" check, performed in non-debug builds
// as well; the other ones should all be guaranteed by the
// CVC4::DType class, but this actually needs to be checked.
AlwaysAssert(!selectorType.getRangeType().isFunctionLike())
<< "cannot put function-like things in datatypes";
}
@@ -1170,4 +1170,4 @@ Kind NodeManager::getKindForFunction(TNode fun)
return kind::UNDEFINED_KIND;
}
-}/* CVC4 namespace */
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -373,7 +373,7 @@ void NodeManager::reclaimZombies() {
// Destroy (call the destructor for) the C++ type representing
// the constant in this NodeValue. This is needed for
- // e.g. CVC4::Rational, since it has a gmp internal
+ // e.g. CVC5::Rational, since it has a gmp internal
// representation that mallocs memory and should be cleaned
// up. (This won't delete a pointer value if used as a
@@ -678,7 +678,7 @@ std::vector<TypeNode> NodeManager::mkMutualDatatypeTypes(
// This next one's a "hard" check, performed in non-debug builds
// as well; the other ones should all be guaranteed by the
- // CVC4::DType class, but this actually needs to be checked.
+ // CVC5::DType class, but this actually needs to be checked.
AlwaysAssert(!selectorType.getRangeType().isFunctionLike())
<< "cannot put function-like things in datatypes";